@@ -1,7 +1,7 @@
 r"""
-Sak is a simple, powerful and clean python common function library.
+pysak is a simple, powerful and clean python common function library.
 
-Github: https://github.com/1Gbps/pysak
+Github Repositories: https://github.com/1Gbps/pysak
 """
 
 SakUserPlatform = None
